cap cd "C:\Users\mwronsk\OneDrive - Szkoła Główna Handlowa w Warszawie\Bank Światowy Rumunia\Replication Minimum Wage - Simulation" 
global Output Output\
global Log Log\

use Data\Tax_data_11_2021_base_for_the_simulation
*Generate auxiliary variables used in the simulation*

gen age=2021-an

gen age_group=1 if age<30
replace age_group=2 if age>29 & age<40
replace age_group=3 if age>39 & age<50
replace age_group=4 if age>49 & age<60
replace age_group=5 if age>59

gen construction=cond1

gen skilled=1 if caen>5800 & caen<6400 
replace skilled=1 if caen>6400 & caen<6631
replace skilled=1 if caen>5900 & caen<7501
replace skilled=1 if caen>8400 & caen<8431
replace skilled=1 if caen>8500 & caen<8561
replace skilled=1 if caen>8600 & caen<8900
replace skilled=1 if caen>9000 & caen<9330
replace skilled=1 if caen==9900

replace skilled=0 if skilled==.


**SIMULATION 1. Increase in MW by 2022 inflation (13.8%)**
gen wage=vbrut

**Scenario 1.Increase of the basic MW to the MW for the construction sector**
gen minwage=2300 if construction==0
replace minwage=3000 if construction==1
gen new_MW_1=2617 if construction==0
replace new_MW_1=3414 if construction==1

gen wagelowold=wage<minwage 
replace wagelowold=. if wage==. | minwage==.
sum  wagelowold, detail

gen wagelownew=wage>=minwage & wage<new_MW_1 
replace wagelownew=. if  wage==. | minwage==.
sum  wagelownew, detail

gen wagehigh=wage>=minwage 
replace wagehigh=. if wage==. | minwage==.

gen expwage=new_MW_1 if wagelownew==1 
replace expwage=wage if  wagelownew!=1
replace expwage=. if wage==.
sum  expwage, detail

gen wagechange=expwage-wage

lab var wagelowold "Wage<minimum wage"
lab var wagelownew "% new minwage>wage>=minwage" 
lab var wage "Wage, EUR"
lab var expwage "Expected wage, all emp., EUR"
lab var wagechange "Expected increase in wage, EUR"

//Elasticities at short- and long- run
local sigma=5
g sigma=-0.`sigma'
g sigma_us=sigma-0.2
g sigmalr=sigma-0.3
g sigma_uslr=sigma_us-0.3

g sigma_sr=sigma*skilled+sigma_us*(1-skilled)
g sigma_lr=sigmalr*skilled+sigma_uslr*(1-skilled)



*Microsimulations***************************************************
********************************************************************
// Assuming that only whose who have minimum wage will loose
//By age, skills, occupation, type of firm and employment compute expected change in wage
//Compute change in wages (New minimum wage respect to group average wage) 

keep if wage>minwage
egen Mwage=mean(wage) if wagelownew==1 , by(gender skilled age_group)
egen Mexpwage=mean(expwage) if wagelownew==1 , by(gender skilled age_group)

gen deltawage=(Mexpwage-Mwage)/Mexpwage
replace deltawage=0 if wagelownew==0 


*Expected Change in Employment (elsticity * wage change)
gen deltaemp_sr=deltawage*sigma_sr
gen deltaemp_lr=deltawage*sigma_lr

local n=200
forval i=1/`n' {
qui{
set seed `i'
gen rann=uniform() if deltaemp_sr!=.

   foreach r in sr lr {
   gen loosejob_`r'=(rann<-deltaemp_`r') if deltaemp_sr!=.
   gen wage_`r'`i'=expwag 
   replace wage_`r'`i'=0 if loosejob_`r'==1
   replace wage_`r'`i'=. if wage==.

   g employed_`r'`i'=1 
   replace employed_`r'`i'=0 if wage_`r'`i'==0
   g unemployed_`r'`i'=1 if wage_`r'`i'==0 
   replace unemployed_`r'`i'=0  if wage_`r'`i'>0 
 
   }

drop rann loosejob_sr loosejob_lr 
}
}


foreach r in sr lr {
egen Mwage_`r'=rowmean(wage_`r'*)
egen SDwage_`r'=rowsd(wage_`r'*)
egen MEDwage_`r'=rowmedian(wage_`r'*)
egen Munemployed_`r'=rowmean(unemployed_`r'*)
egen Memployed_`r'=rowmean(employed_`r'*)


}


save Data_ready\11_2021_only_sample_full_time_scenario_1.dta, replace
****************************************************************************
*Labeling*******************************************************************
lab var wage "Actual wage. EUR"
lab var expwage  "Expected wage assuming no loose of employment. EUR"
lab var Mwage_sr  "Simulated wage. Short-run. EUR"
lab var Memployed_sr "Simulated employment rate. Short-run. %"
lab var Munemployed_sr "Simulated unemployment rate. Short-run %"
lab var Mwage_lr  "Simulated wage. Long-run. EUR"
lab var Memployed_lr "Simulated employment rate. Long-run. %"
lab var Munemployed_lr "Simulated unemployment rate. Long-run %"

//Summary by age
global outcome  wage expwage Mwage_sr Memployed_sr  Munemployed_sr   Mwage_lr  Memployed_lr Munemployed_lr ///


foreach var in All age_group {

preserve 
collapse  $outcome, by(`var')

lab var wage "Actual wage. EUR"
lab var expwage  "Expected wage assuming no loose of employment. EUR"
lab var Mwage_sr  "Simulated wage. Short-run. EUR"
lab var Memployed_sr "Simulated employment rate. Short-run. %"
lab var Munemployed_sr "Simulated unemployment rate. Short-run %"
lab var Mwage_lr  "Simulated wage. Long-run. EUR"
lab var Memployed_lr "Simulated employment rate. Long-run. %"
lab var Munemployed_lr "Simulated unemployment rate. Long-run %"


export excel  using $Output\Romania_MW_sim_tax_1.xlsx, sheet("`var'") firstrow(varlabels) cell(A2) sheetreplace   
restore 
}

foreach var in All age_group {

preserve 
collapse  $outcome  if wagelownew==1, by(`var')

lab var wage "Actual wage. EUR"
lab var expwage  "Expected wage assuming no loose of employment. EUR"
lab var Mwage_sr  "Simulated wage. Short-run. EUR"
lab var Memployed_sr "Simulated employment rate. Short-run. %"
lab var Munemployed_sr "Simulated unemployment rate. Short-run %"
lab var Mwage_lr  "Simulated wage. Long-run. EUR"
lab var Memployed_lr "Simulated employment rate. Long-run. %"
lab var Munemployed_lr "Simulated unemployment rate. Long-run %"


export excel  using $Output\Romania_MW_sim_tax_1.xlsx, sheet("0nly affected `var'") firstrow(varlabels) cell(A2) sheetreplace   

restore 
}
